summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/iris/xmpp-im
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/jabber/libiris/iris/xmpp-im
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/libiris/iris/xmpp-im')
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp142
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/types.cpp111
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp128
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.h62
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_vcard.cpp4
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_xmlcommon.cpp2
6 files changed, 236 insertions, 213 deletions
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/types.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/types.cpp
index f2fcf7c9..fb9de2e8 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/types.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/types.cpp
@@ -274,7 +274,7 @@ TQString Message::subject(const TQString &lang) const
//! This function will return a plain text or the Richtext version if it
//! it exists.
//! \param rich - Returns richtext if true and plain text if false. (default: false)
-//! \note Richtext is in Qt's richtext format and not in xhtml.
+//! \note Richtext is in TQt's richtext format and not in xhtml.
TQString Message::body(const TQString &lang) const
{
return d->body[lang];
@@ -295,7 +295,7 @@ Stanza::Error Message::error() const
return d->error;
}
-//! \brief Set receivers information
+//! \brief Set tqreceivers information
//!
//! \param to - Receivers Jabber id
void Message::setTo(const Jid &j)
@@ -421,12 +421,12 @@ bool Message::containsEvents() const
bool Message::containsEvent(MsgEvent e) const
{
- return d->eventList.contains(e);
+ return d->eventList.tqcontains(e);
}
void Message::addEvent(MsgEvent e)
{
- if (!d->eventList.contains(e)) {
+ if (!d->eventList.tqcontains(e)) {
if (e == CancelEvent || containsEvent(CancelEvent))
d->eventList.clear(); // Reset list
d->eventList += e;
@@ -503,17 +503,17 @@ Stanza Message::toStanza(Stream *stream) const
}
}
if ( !d->xHTMLBody.isEmpty()) {
- TQDomElement parent = s.createElement(s.xhtmlImNS(), "html");
+ TQDomElement tqparent = s.createElement(s.xhtmlImNS(), "html");
for(it = d->xHTMLBody.begin(); it != d->xHTMLBody.end(); ++it) {
const TQString &str = it.data();
if(!str.isEmpty()) {
TQDomElement child = s.createXHTMLElement(str);
if(!it.key().isEmpty())
child.setAttributeNS(NS_XML, "xml:lang", it.key());
- parent.appendChild(child);
+ tqparent.appendChild(child);
}
}
- s.appendChild(parent);
+ s.appendChild(tqparent);
}
if(d->type == "error")
s.setError(d->error);
@@ -658,7 +658,7 @@ bool Message::fromStanza(const Stanza &s, int timeZoneOffset)
if(e.tagName() == "active")
{
//like in JEP-0022 we let the client know that we can receive ComposingEvent
- // (we can do that according to §4.6 of the JEP-0085)
+ // (we can do that according to �4.6 of the JEP-0085)
d->eventList += ComposingEvent;
d->eventList += InactiveEvent;
d->eventList += GoneEvent;
@@ -697,7 +697,7 @@ bool Message::fromStanza(const Stanza &s, int timeZoneOffset)
d->spooled = true;
}
else {
- d->timeStamp = TQDateTime::currentDateTime();
+ d->timeStamp = TQDateTime::tqcurrentDateTime();
d->spooled = false;
}
@@ -801,100 +801,100 @@ bool Subscription::fromString(const TQString &s)
//---------------------------------------------------------------------------
-// Status
+// tqStatus
//---------------------------------------------------------------------------
-Status::Status(const TQString &show, const TQString &status, int priority, bool available)
+tqStatus::tqStatus(const TQString &show, const TQString &status, int priority, bool available)
{
v_isAvailable = available;
v_show = show;
v_status = status;
v_priority = priority;
- v_timeStamp = TQDateTime::currentDateTime();
+ v_timeStamp = TQDateTime::tqcurrentDateTime();
v_isInvisible = false;
ecode = -1;
}
-Status::~Status()
+tqStatus::~tqStatus()
{
}
-bool Status::hasError() const
+bool tqStatus::hasError() const
{
return (ecode != -1);
}
-void Status::setError(int code, const TQString &str)
+void tqStatus::setError(int code, const TQString &str)
{
ecode = code;
estr = str;
}
-void Status::setIsAvailable(bool available)
+void tqStatus::setIsAvailable(bool available)
{
v_isAvailable = available;
}
-void Status::setIsInvisible(bool invisible)
+void tqStatus::setIsInvisible(bool invisible)
{
v_isInvisible = invisible;
}
-void Status::setPriority(int x)
+void tqStatus::setPriority(int x)
{
v_priority = x;
}
-void Status::setShow(const TQString & _show)
+void tqStatus::setShow(const TQString & _show)
{
v_show = _show;
}
-void Status::setStatus(const TQString & _status)
+void tqStatus::settqStatus(const TQString & _status)
{
v_status = _status;
}
-void Status::setTimeStamp(const TQDateTime & _timestamp)
+void tqStatus::setTimeStamp(const TQDateTime & _timestamp)
{
v_timeStamp = _timestamp;
}
-void Status::setKeyID(const TQString &key)
+void tqStatus::setKeyID(const TQString &key)
{
v_key = key;
}
-void Status::setXSigned(const TQString &s)
+void tqStatus::setXSigned(const TQString &s)
{
v_xsigned = s;
}
-void Status::setSongTitle(const TQString & _songtitle)
+void tqStatus::setSongTitle(const TQString & _songtitle)
{
v_songTitle = _songtitle;
}
-void Status::setCapsNode(const TQString & _capsNode)
+void tqStatus::setCapsNode(const TQString & _capsNode)
{
v_capsNode = _capsNode;
}
-void Status::setCapsVersion(const TQString & _capsVersion)
+void tqStatus::setCapsVersion(const TQString & _capsVersion)
{
v_capsVersion = _capsVersion;
}
-void Status::setCapsExt(const TQString & _capsExt)
+void tqStatus::setCapsExt(const TQString & _capsExt)
{
v_capsExt = _capsExt;
}
-bool Status::isAvailable() const
+bool tqStatus::isAvailable() const
{
return v_isAvailable;
}
-bool Status::isAway() const
+bool tqStatus::isAway() const
{
if(v_show == "away" || v_show == "xa" || v_show == "dnd")
return true;
@@ -902,66 +902,66 @@ bool Status::isAway() const
return false;
}
-bool Status::isInvisible() const
+bool tqStatus::isInvisible() const
{
return v_isInvisible;
}
-int Status::priority() const
+int tqStatus::priority() const
{
return v_priority;
}
-const TQString & Status::show() const
+const TQString & tqStatus::show() const
{
return v_show;
}
-const TQString & Status::status() const
+const TQString & tqStatus::status() const
{
return v_status;
}
-TQDateTime Status::timeStamp() const
+TQDateTime tqStatus::timeStamp() const
{
return v_timeStamp;
}
-const TQString & Status::keyID() const
+const TQString & tqStatus::keyID() const
{
return v_key;
}
-const TQString & Status::xsigned() const
+const TQString & tqStatus::xsigned() const
{
return v_xsigned;
}
-const TQString & Status::songTitle() const
+const TQString & tqStatus::songTitle() const
{
return v_songTitle;
}
-const TQString & Status::capsNode() const
+const TQString & tqStatus::capsNode() const
{
return v_capsNode;
}
-const TQString & Status::capsVersion() const
+const TQString & tqStatus::capsVersion() const
{
return v_capsVersion;
}
-const TQString & Status::capsExt() const
+const TQString & tqStatus::capsExt() const
{
return v_capsExt;
}
-int Status::errorCode() const
+int tqStatus::errorCode() const
{
return ecode;
}
-const TQString & Status::errorString() const
+const TQString & tqStatus::errorString() const
{
return estr;
}
@@ -970,7 +970,7 @@ const TQString & Status::errorString() const
//---------------------------------------------------------------------------
// Resource
//---------------------------------------------------------------------------
-Resource::Resource(const TQString &name, const Status &stat)
+Resource::Resource(const TQString &name, const tqStatus &stat)
{
v_name = name;
v_status = stat;
@@ -990,7 +990,7 @@ int Resource::priority() const
return v_status.priority();
}
-const Status & Resource::status() const
+const tqStatus & Resource::status() const
{
return v_status;
}
@@ -1000,7 +1000,7 @@ void Resource::setName(const TQString & _name)
v_name = _name;
}
-void Resource::setStatus(const Status & _status)
+void Resource::settqStatus(const tqStatus & _status)
{
v_status = _status;
}
@@ -1018,10 +1018,10 @@ ResourceList::~ResourceList()
{
}
-ResourceList::Iterator ResourceList::find(const TQString & _find)
+ResourceList::Iterator ResourceList::tqfind(const TQString & _tqfind)
{
for(ResourceList::Iterator it = begin(); it != end(); ++it) {
- if((*it).name() == _find)
+ if((*it).name() == _tqfind)
return it;
}
@@ -1040,10 +1040,10 @@ ResourceList::Iterator ResourceList::priority()
return highest;
}
-ResourceList::ConstIterator ResourceList::find(const TQString & _find) const
+ResourceList::ConstIterator ResourceList::tqfind(const TQString & _tqfind) const
{
for(ResourceList::ConstIterator it = begin(); it != end(); ++it) {
- if((*it).name() == _find)
+ if((*it).name() == _tqfind)
return it;
}
@@ -1222,7 +1222,7 @@ Roster::~Roster()
{
}
-Roster::Iterator Roster::find(const Jid &j)
+Roster::Iterator Roster::tqfind(const Jid &j)
{
for(Roster::Iterator it = begin(); it != end(); ++it) {
if((*it).jid().compare(j))
@@ -1232,7 +1232,7 @@ Roster::Iterator Roster::find(const Jid &j)
return end();
}
-Roster::ConstIterator Roster::find(const Jid &j) const
+Roster::ConstIterator Roster::tqfind(const Jid &j) const
{
for(Roster::ConstIterator it = begin(); it != end(); ++it) {
if((*it).jid().compare(j))
@@ -1512,7 +1512,7 @@ bool Features::test(const TQStringList &ns) const
{
TQStringList::ConstIterator it = ns.begin();
for ( ; it != ns.end(); ++it)
- if ( _list.find( *it ) != _list.end() )
+ if ( _list.tqfind( *it ) != _list.end() )
return true;
return false;
@@ -1597,12 +1597,13 @@ bool Features::haveVCard() const
// custom Psi acitons
#define FID_ADD "psi:add"
-class Features::FeatureName : public QObject
+class Features::FeatureName : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
FeatureName()
- : TQObject(qApp)
+ : TQObject(tqApp)
{
id2s[FID_Invalid] = tr("ERROR: Incorrect usage of Features class");
id2s[FID_None] = tr("None");
@@ -1866,7 +1867,7 @@ TQString DiscoItem::action2string(Action a)
else if ( a == Remove )
s = "remove";
else
- s = TQString::null;
+ s = TQString();
return s;
}
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.h b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.h
index c8085013..9d5125d9 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.h
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.h
@@ -30,13 +30,14 @@
namespace XMPP
{
class Roster;
- class Status;
+ class tqStatus;
class JT_Register : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_Register(Task *parent);
+ JT_Register(Task *tqparent);
~JT_Register();
void reg(const TQString &user, const TQString &pass);
@@ -61,8 +62,9 @@ namespace XMPP
class JT_UnRegister : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_UnRegister(Task *parent);
+ JT_UnRegister(Task *tqparent);
~JT_UnRegister();
void unreg(const Jid &);
@@ -81,8 +83,9 @@ namespace XMPP
class JT_Roster : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_Roster(Task *parent);
+ JT_Roster(Task *tqparent);
~JT_Roster();
void get();
@@ -109,8 +112,9 @@ namespace XMPP
class JT_PushRoster : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_PushRoster(Task *parent);
+ JT_PushRoster(Task *tqparent);
~JT_PushRoster();
bool take(const TQDomElement &);
@@ -126,12 +130,13 @@ namespace XMPP
class JT_Presence : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_Presence(Task *parent);
+ JT_Presence(Task *tqparent);
~JT_Presence();
- void pres(const Status &);
- void pres(const Jid &, const Status &);
+ void pres(const tqStatus &);
+ void pres(const Jid &, const tqStatus &);
void sub(const Jid &, const TQString &subType);
void onGo();
@@ -147,14 +152,15 @@ namespace XMPP
class JT_PushPresence : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_PushPresence(Task *parent);
+ JT_PushPresence(Task *tqparent);
~JT_PushPresence();
bool take(const TQDomElement &);
signals:
- void presence(const Jid &, const Status &);
+ void presence(const Jid &, const tqStatus &);
void subscription(const Jid &, const TQString &);
private:
@@ -165,8 +171,9 @@ namespace XMPP
class JT_Message : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_Message(Task *parent, const Message &);
+ JT_Message(Task *tqparent, const Message &);
~JT_Message();
void onGo();
@@ -181,8 +188,9 @@ namespace XMPP
class JT_PushMessage : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_PushMessage(Task *parent);
+ JT_PushMessage(Task *tqparent);
~JT_PushMessage();
bool take(const TQDomElement &);
@@ -198,6 +206,7 @@ namespace XMPP
class JT_GetLastActivity : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_GetLastActivity(Task *);
~JT_GetLastActivity();
@@ -221,6 +230,7 @@ namespace XMPP
class JT_GetServices : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_GetServices(Task *);
@@ -243,8 +253,9 @@ namespace XMPP
class JT_VCard : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_VCard(Task *parent);
+ JT_VCard(Task *tqparent);
~JT_VCard();
void get(const Jid &);
@@ -266,8 +277,9 @@ namespace XMPP
class JT_Search : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_Search(Task *parent);
+ JT_Search(Task *tqparent);
~JT_Search();
const Form & form() const;
@@ -290,6 +302,7 @@ namespace XMPP
class JT_ClientVersion : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_ClientVersion(Task *);
@@ -312,6 +325,7 @@ namespace XMPP
class JT_ClientTime : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_ClientTime(Task *, const Jid &);
@@ -329,6 +343,7 @@ namespace XMPP
class JT_ServInfo : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_ServInfo(Task *);
~JT_ServInfo();
@@ -339,6 +354,7 @@ namespace XMPP
class JT_Gateway : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_Gateway(Task *);
@@ -362,6 +378,7 @@ namespace XMPP
class JT_Browse : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_Browse(Task *);
~JT_Browse();
@@ -384,11 +401,12 @@ namespace XMPP
class JT_DiscoItems : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_DiscoItems(Task *);
~JT_DiscoItems();
- void get(const Jid &, const TQString &node = TQString::null);
+ void get(const Jid &, const TQString &node = TQString());
void get(const DiscoItem &);
const DiscoList &items() const;
@@ -404,11 +422,12 @@ namespace XMPP
class JT_DiscoInfo : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_DiscoInfo(Task *);
~JT_DiscoInfo();
- void get(const Jid &, const TQString &node = TQString::null, const DiscoItem::Identity = DiscoItem::Identity());
+ void get(const Jid &, const TQString &node = TQString(), const DiscoItem::Identity = DiscoItem::Identity());
void get(const DiscoItem &);
const DiscoItem &item() const;
@@ -426,6 +445,7 @@ namespace XMPP
class JT_DiscoPublish : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
JT_DiscoPublish(Task *);
~JT_DiscoPublish();
@@ -443,12 +463,13 @@ namespace XMPP
class JT_MucPresence : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_MucPresence(Task *parent);
+ JT_MucPresence(Task *tqparent);
~JT_MucPresence();
- void pres(const Status &);
- void pres(const Jid &, const Status &, const TQString &password);
+ void pres(const tqStatus &);
+ void pres(const Jid &, const tqStatus &, const TQString &password);
void onGo();
@@ -463,8 +484,9 @@ namespace XMPP
class JT_PrivateStorage : public Task
{
Q_OBJECT
+ TQ_OBJECT
public:
- JT_PrivateStorage(Task *parent);
+ JT_PrivateStorage(Task *tqparent);
~JT_PrivateStorage();
void set(const TQDomElement &);
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_vcard.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_vcard.cpp
index 5f5214fd..009f0136 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_vcard.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_vcard.cpp
@@ -81,7 +81,7 @@ static TQString subTagText(const TQDomElement &e, const TQString &name)
TQDomElement i = findSubTag(e, name, &found);
if ( found )
return i.text().stripWhiteSpace();
- return TQString::null;
+ return TQString();
}
using namespace XMPP;
@@ -93,7 +93,7 @@ static TQString image2type(const TQByteArray &ba)
{
TQBuffer buf(ba);
buf.open(IO_ReadOnly);
- TQString format = TQImageIO::imageFormat( &buf );
+ TQString format = TQImageIO::imageFormat( TQT_TQIODEVICE(&buf) );
// TODO: add more formats
if ( format == "PNG" || format == "PsiPNG" )
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_xmlcommon.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_xmlcommon.cpp
index d7b5c82d..65c3b8b3 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_xmlcommon.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_xmlcommon.cpp
@@ -185,7 +185,7 @@ TQString subTagText(const TQDomElement &e, const TQString &name)
TQDomElement i = findSubTag(e, name, &found);
if ( found )
return i.text();
- return TQString::null;
+ return TQString();
}
TQDomElement textTag(TQDomDocument &doc, const TQString &name, const TQString &content)
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
index c78875bc..9d56467c 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
@@ -34,8 +34,8 @@
//! Client, you will need to manually invoke Tasks. Fortunately, the
//! process is very simple.
//!
//! The entire Task system is heavily founded on Qt. All Tasks have a parent,
//! except for the root Task, and are considered QObjects. By using Qt's RTTI
//! facilities (TQObject::sender(), TQObject::isA(), etc), you can use a
//! "fire and forget" approach with Tasks.
//!
@@ -96,7 +96,7 @@
using namespace Jabber;*/
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
#define vsnprintf _vsnprintf
#endif
@@ -191,7 +191,7 @@ void Client::connectToServer(ClientStream *s, const Jid &j, bool auth)
//connect(d->stream, TQT_SIGNAL(connected()), TQT_SLOT(streamConnected()));
//connect(d->stream, TQT_SIGNAL(handshaken()), TQT_SLOT(streamHandshaken()));
connect(d->stream, TQT_SIGNAL(error(int)), TQT_SLOT(streamError(int)));
- //connect(d->stream, TQT_SIGNAL(sslCertificateReady(const QSSLCert &)), TQT_SLOT(streamSSLCertificateReady(const QSSLCert &)));
+ //connect(d->stream, TQT_SIGNAL(sslCertificateReady(const TQSSLCert &)), TQT_SLOT(streamSSLCertificateReady(const TQSSLCert &)));
connect(d->stream, TQT_SIGNAL(readyRead()), TQT_SLOT(streamReadyRead()));
//connect(d->stream, TQT_SIGNAL(closeFinished()), TQT_SLOT(streamCloseFinished()));
connect(d->stream, TQT_SIGNAL(incomingXml(const TQString &)), TQT_SLOT(streamIncomingXml(const TQString &)));
@@ -208,13 +208,13 @@ void Client::start(const TQString &host, const TQString &user, const TQString &p
d->pass = pass;
d->resource = _resource;
- Status stat;
+ tqStatus stat;
stat.setIsAvailable(false);
d->resourceList += Resource(resource(), stat);
JT_PushPresence *pp = new JT_PushPresence(rootTask());
connect(pp, TQT_SIGNAL(subscription(const Jid &, const TQString &)), TQT_SLOT(ppSubscription(const Jid &, const TQString &)));
- connect(pp, TQT_SIGNAL(presence(const Jid &, const Status &)), TQT_SLOT(ppPresence(const Jid &, const Status &)));
+ connect(pp, TQT_SIGNAL(presence(const Jid &, const tqStatus &)), TQT_SLOT(ppPresence(const Jid &, const tqStatus &)));
JT_PushMessage *pm = new JT_PushMessage(rootTask());
connect(pm, TQT_SIGNAL(message(const Message &)), TQT_SLOT(pmMessage(const Message &)));
@@ -266,7 +266,7 @@ bool Client::isActive() const
return d->active;
}
-void Client::groupChatChangeNick(const TQString &host, const TQString &room, const TQString &nick, const Status &_s)
+void Client::groupChatChangeNick(const TQString &host, const TQString &room, const TQString &nick, const tqStatus &_s)
{
Jid jid(room + "@" + host + "/" + nick);
for(TQValueList<GroupChat>::Iterator it = d->groupChatList.begin(); it != d->groupChatList.end(); it++) {
@@ -274,7 +274,7 @@ void Client::groupChatChangeNick(const TQString &host, const TQString &room, con
if(i.j.compare(jid, false)) {
i.j = jid;
- Status s = _s;
+ tqStatus s = _s;
s.setIsAvailable(true);
JT_Presence *j = new JT_Presence(rootTask());
@@ -302,14 +302,14 @@ bool Client::groupChatJoin(const TQString &host, const TQString &room, const TQS
++it;
}
- debug(TQString("Client: Joined: [%1]\n").arg(jid.full()));
+ debug(TQString("Client: Joined: [%1]\n").tqarg(jid.full()));
GroupChat i;
i.j = jid;
i.status = GroupChat::Connecting;
d->groupChatList += i;
JT_Presence *j = new JT_Presence(rootTask());
- j->pres(jid, Status());
+ j->pres(jid, tqStatus());
j->go(true);
return true;
@@ -331,20 +331,20 @@ bool Client::groupChatJoin(const TQString &host, const TQString &room, const TQS
++it;
}
- debug(TQString("Client: Joined: [%1]\n").arg(jid.full()));
+ debug(TQString("Client: Joined: [%1]\n").tqarg(jid.full()));
GroupChat i;
i.j = jid;
i.status = GroupChat::Connecting;
d->groupChatList += i;
JT_MucPresence *j = new JT_MucPresence(rootTask());
- j->pres(jid, Status(), password);
+ j->pres(jid, tqStatus(), password);
j->go(true);
return true;
}
-void Client::groupChatSetStatus(const TQString &host, const TQString &room, const Status &_s)
+void Client::groupChatSettqStatus(const TQString &host, const TQString &room, const tqStatus &_s)
{
Jid jid(room + "@" + host);
bool found = false;
@@ -359,7 +359,7 @@ void Client::groupChatSetStatus(const TQString &host, const TQString &room, cons
if(!found)
return;
- Status s = _s;
+ tqStatus s = _s;
s.setIsAvailable(true);
JT_Presence *j = new JT_Presence(rootTask());
@@ -377,10 +377,10 @@ void Client::groupChatLeave(const TQString &host, const TQString &room)
continue;
i.status = GroupChat::Closing;
- debug(TQString("Client: Leaving: [%1]\n").arg(i.j.full()));
+ debug(TQString("Client: Leaving: [%1]\n").tqarg(i.j.full()));
JT_Presence *j = new JT_Presence(rootTask());
- Status s;
+ tqStatus s;
s.setIsAvailable(false);
j->pres(i.j, s);
j->go(true);
@@ -409,7 +409,7 @@ void Client::close(bool)
i.status = GroupChat::Closing;
JT_Presence *j = new JT_Presence(rootTask());
- Status s;
+ tqStatus s;
s.setIsAvailable(false);
j->pres(i.j, s);
j->go(true);
@@ -457,7 +457,7 @@ void Client::streamError(int)
//}
}
-/*void Client::streamSSLCertificateReady(const QSSLCert &cert)
+/*void Client::streamSSLCertificateReady(const TQSSLCert &cert)
{
sslCertReady(cert);
}
@@ -469,10 +469,10 @@ void Client::streamCloseFinished()
static TQDomElement oldStyleNS(const TQDomElement &e)
{
- // find closest parent with a namespace
- TQDomNode par = e.parentNode();
+ // find closest tqparent with a namespace
+ TQDomNode par = e.tqparentNode();
while(!par.isNull() && par.namespaceURI().isNull())
- par = par.parentNode();
+ par = par.tqparentNode();
bool noShowNS = false;
if(!par.isNull() && par.namespaceURI() == e.namespaceURI())
noShowNS = true;
@@ -492,7 +492,7 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
if(!noShowNS)
i.setAttribute("xmlns", e.namespaceURI());
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -513,7 +513,7 @@ void Client::streamReadyRead()
Stanza s = d->stream->read();
TQString out = s.toString();
- debug(TQString("Client: incoming: [\n%1]\n").arg(out));
+ debug(TQString("Client: incoming: [\n%1]\n").tqarg(out));
xmlIncoming(out);
TQDomElement x = oldStyleNS(s.element());
@@ -588,7 +588,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
// find closest xmlns
TQDomNode n = e;
while(!n.isNull() && !n.toElement().hasAttribute("xmlns"))
- n = n.parentNode();
+ n = n.tqparentNode();
TQString ns;
if(n.isNull() || !n.toElement().hasAttribute("xmlns"))
ns = "jabber:client";
@@ -606,7 +606,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
i.setAttributeNodeNS(a.cloneNode().toAttr());
}
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -630,7 +630,7 @@ void Client::send(const TQDomElement &x)
//x.save(ts, 0);
//TQString out = Stream::xmlToString(x);
- //debug(TQString("Client: outgoing: [\n%1]\n").arg(out));
+ //debug(TQString("Client: outgoing: [\n%1]\n").tqarg(out));
//xmlOutgoing(out);
TQDomElement e = addCorrectNS(x);
@@ -641,7 +641,7 @@ void Client::send(const TQDomElement &x)
}
TQString out = s.toString();
- debug(TQString("Client: outgoing: [\n%1]\n").arg(out));
+ debug(TQString("Client: outgoing: [\n%1]\n").tqarg(out));
xmlOutgoing(out);
//printf("x[%s] x2[%s] s[%s]\n", Stream::xmlToString(x).latin1(), Stream::xmlToString(e).latin1(), s.toString().latin1());
@@ -653,7 +653,7 @@ void Client::send(const TQString &str)
if(!d->stream)
return;
- debug(TQString("Client: outgoing: [\n%1]\n").arg(str));
+ debug(TQString("Client: outgoing: [\n%1]\n").tqarg(str));
xmlOutgoing(str);
static_cast<ClientStream*>(d->stream)->writeDirect(str);
}
@@ -712,12 +712,12 @@ void Client::ppSubscription(const Jid &j, const TQString &s)
subscription(j, s);
}
-void Client::ppPresence(const Jid &j, const Status &s)
+void Client::ppPresence(const Jid &j, const tqStatus &s)
{
if(s.isAvailable())
- debug(TQString("Client: %1 is available.\n").arg(j.full()));
+ debug(TQString("Client: %1 is available.\n").tqarg(j.full()));
else
- debug(TQString("Client: %1 is unavailable.\n").arg(j.full()));
+ debug(TQString("Client: %1 is unavailable.\n").tqarg(j.full()));
for(TQValueList<GroupChat>::Iterator it = d->groupChatList.begin(); it != d->groupChatList.end(); it++) {
GroupChat &i = *it;
@@ -725,7 +725,7 @@ void Client::ppPresence(const Jid &j, const Status &s)
if(i.j.compare(j, false)) {
bool us = (i.j.resource() == j.resource() || j.resource().isEmpty()) ? true: false;
- debug(TQString("for groupchat i=[%1] pres=[%2], [us=%3].\n").arg(i.j.full()).arg(j.full()).arg(us));
+ debug(TQString("for groupchat i=[%1] pres=[%2], [us=%3].\n").tqarg(i.j.full()).tqarg(j.full()).tqarg(us));
switch(i.status) {
case GroupChat::Connecting:
if(us && s.hasError()) {
@@ -788,16 +788,16 @@ void Client::ppPresence(const Jid &j, const Status &s)
}
}
-void Client::updateSelfPresence(const Jid &j, const Status &s)
+void Client::updateSelfPresence(const Jid &j, const tqStatus &s)
{
- ResourceList::Iterator rit = d->resourceList.find(j.resource());
+ ResourceList::Iterator rit = d->resourceList.tqfind(j.resource());
bool found = (rit == d->resourceList.end()) ? false: true;
// unavailable? remove the resource
if(!s.isAvailable()) {
if(found) {
- debug(TQString("Client: Removing self resource: name=[%1]\n").arg(j.resource()));
- (*rit).setStatus(s);
+ debug(TQString("Client: Removing self resource: name=[%1]\n").tqarg(j.resource()));
+ (*rit).settqStatus(s);
resourceUnavailable(j, *rit);
d->resourceList.remove(rit);
}
@@ -808,31 +808,31 @@ void Client::updateSelfPresence(const Jid &j, const Status &s)
if(!found) {
r = Resource(j.resource(), s);
d->resourceList += r;
- debug(TQString("Client: Adding self resource: name=[%1]\n").arg(j.resource()));
+ debug(TQString("Client: Adding self resource: name=[%1]\n").tqarg(j.resource()));
}
else {
- (*rit).setStatus(s);
+ (*rit).settqStatus(s);
r = *rit;
- debug(TQString("Client: Updating self resource: name=[%1]\n").arg(j.resource()));
+ debug(TQString("Client: Updating self resource: name=[%1]\n").tqarg(j.resource()));
}
resourceAvailable(j, r);
}
}
-void Client::updatePresence(LiveRosterItem *i, const Jid &j, const Status &s)
+void Client::updatePresence(LiveRosterItem *i, const Jid &j, const tqStatus &s)
{
- ResourceList::Iterator rit = i->resourceList().find(j.resource());
+ ResourceList::Iterator rit = i->resourceList().tqfind(j.resource());
bool found = (rit == i->resourceList().end()) ? false: true;
// unavailable? remove the resource
if(!s.isAvailable()) {
if(found) {
- (*rit).setStatus(s);
- debug(TQString("Client: Removing resource from [%1]: name=[%2]\n").arg(i->jid().full()).arg(j.resource()));
+ (*rit).settqStatus(s);
+ debug(TQString("Client: Removing resource from [%1]: name=[%2]\n").tqarg(i->jid().full()).tqarg(j.resource()));
resourceUnavailable(j, *rit);
i->resourceList().remove(rit);
- i->setLastUnavailableStatus(s);
+ i->setLastUnavailabletqStatus(s);
}
}
// available? add/update the resource
@@ -841,12 +841,12 @@ void Client::updatePresence(LiveRosterItem *i, const Jid &j, const Status &s)
if(!found) {
r = Resource(j.resource(), s);
i->resourceList() += r;
- debug(TQString("Client: Adding resource to [%1]: name=[%2]\n").arg(i->jid().full()).arg(j.resource()));
+ debug(TQString("Client: Adding resource to [%1]: name=[%2]\n").tqarg(i->jid().full()).tqarg(j.resource()));
}
else {
- (*rit).setStatus(s);
+ (*rit).settqStatus(s);
r = *rit;
- debug(TQString("Client: Updating resource to [%1]: name=[%2]\n").arg(i->jid().full()).arg(j.resource()));
+ debug(TQString("Client: Updating resource to [%1]: name=[%2]\n").tqarg(i->jid().full()).tqarg(j.resource()));
}
resourceAvailable(j, r);
@@ -855,7 +855,7 @@ void Client::updatePresence(LiveRosterItem *i, const Jid &j, const Status &s)
void Client::pmMessage(const Message &m)
{
- debug(TQString("Client: Message from %1\n").arg(m.from().full()));
+ debug(TQString("Client: Message from %1\n").tqarg(m.from().full()));
if(m.type() == "groupchat") {
for(TQValueList<GroupChat>::Iterator it = d->groupChatList.begin(); it != d->groupChatList.end(); it++) {
@@ -950,7 +950,7 @@ void Client::importRosterItem(const RosterItem &item)
// Remove
if(item.subscription().type() == Subscription::Remove) {
- LiveRoster::Iterator it = d->roster.find(item.jid());
+ LiveRoster::Iterator it = d->roster.tqfind(item.jid());
if(it != d->roster.end()) {
rosterItemRemoved(*it);
d->roster.remove(it);
@@ -959,7 +959,7 @@ void Client::importRosterItem(const RosterItem &item)
}
// Add/Update
else {
- LiveRoster::Iterator it = d->roster.find(item.jid());
+ LiveRoster::Iterator it = d->roster.tqfind(item.jid());
if(it != d->roster.end()) {
LiveRosterItem &i = *it;
i.setFlagForDelete(false);
@@ -993,7 +993,7 @@ void Client::sendSubscription(const Jid &jid, const TQString &type)
j->go(true);
}
-void Client::setPresence(const Status &s)
+void Client::setPresence(const tqStatus &s)
{
JT_Presence *j = new JT_Presence(rootTask());
j->pres(s);
@@ -1001,9 +1001,9 @@ void Client::setPresence(const Status &s)
// update our resourceList
ppPresence(jid(), s);
- //ResourceList::Iterator rit = d->resourceList.find(resource());
+ //ResourceList::Iterator rit = d->resourceList.tqfind(resource());
//Resource &r = *rit;
- //r.setStatus(s);
+ //r.settqStatus(s);
}
TQString Client::OSName() const
@@ -1097,7 +1097,7 @@ void Client::addExtension(const TQString& ext, const Features& features)
void Client::removeExtension(const TQString& ext)
{
- if (d->extension_features.contains(ext)) {
+ if (d->extension_features.tqcontains(ext)) {
d->extension_features.remove(ext);
d->capsExt = extensions().join(" ");
}
@@ -1155,22 +1155,22 @@ public:
bool done;
};
-Task::Task(Task *parent)
-:TQObject(parent)
+Task::Task(Task *tqparent)
+:TQObject(tqparent)
{
init();
- d->client = parent->client();
+ d->client = tqparent->client();
d->id = client()->genUniqueId();
connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
}
-Task::Task(Client *parent, bool)
+Task::Task(Client *tqparent, bool)
:TQObject(0)
{
init();
- d->client = parent;
+ d->client = tqparent;
connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
}
@@ -1189,9 +1189,9 @@ void Task::init()
d->done = false;
}
-Task *Task::parent() const
+Task *Task::tqparent() const
{
- return (Task *)TQObject::parent();
+ return (Task *)TQObject::tqparent();
}
Client *Task::client() const
@@ -1233,12 +1233,12 @@ void Task::go(bool autoDelete)
bool Task::take(const TQDomElement &x)
{
- const TQObjectList *p = children();
- if(!p)
+ const TQObjectList p = childrenListObject();
+ if(p.isEmpty())
return false;
// pass along the xml
- TQObjectListIt it(*p);
+ TQObjectListIt it(p);
Task *t;
for(; it.current(); ++it) {
TQObject *obj = it.current();
@@ -1362,7 +1362,7 @@ void Task::debug(const char *fmt, ...)
void Task::debug(const TQString &str)
{
- client()->debug(TQString("%1: ").arg(className()) + str);
+ client()->debug(TQString("%1: ").tqarg(className()) + str);
}
bool Task::iqVerify(const TQDomElement &x, const Jid &to, const TQString &id, const TQString &xmlns)
@@ -1461,9 +1461,9 @@ bool LiveRosterItem::isAvailable() const
return false;
}
-const Status & LiveRosterItem::lastUnavailableStatus() const
+const tqStatus & LiveRosterItem::lastUnavailabletqStatus() const
{
- return v_lastUnavailableStatus;
+ return v_lastUnavailabletqStatus;
}
bool LiveRosterItem::flagForDelete() const
@@ -1471,9 +1471,9 @@ bool LiveRosterItem::flagForDelete() const
return v_flagForDelete;
}
-void LiveRosterItem::setLastUnavailableStatus(const Status &s)
+void LiveRosterItem::setLastUnavailabletqStatus(const tqStatus &s)
{
- v_lastUnavailableStatus = s;
+ v_lastUnavailabletqStatus = s;
}
void LiveRosterItem::setFlagForDelete(bool b)
@@ -1499,7 +1499,7 @@ void LiveRoster::flagAllForDelete()
(*it).setFlagForDelete(true);
}
-LiveRoster::Iterator LiveRoster::find(const Jid &j, bool compareRes)
+LiveRoster::Iterator LiveRoster::tqfind(const Jid &j, bool compareRes)
{
Iterator it;
for(it = begin(); it != end(); ++it) {
@@ -1509,7 +1509,7 @@ LiveRoster::Iterator LiveRoster::find(const Jid &j, bool compareRes)
return it;
}
-LiveRoster::ConstIterator LiveRoster::find(const Jid &j, bool compareRes) const
+LiveRoster::ConstIterator LiveRoster::tqfind(const Jid &j, bool compareRes) const
{
ConstIterator it;
for(it = begin(); it != end(); ++it) {
@@ -34,8 +34,8 @@
//! process is very simple.
//!
-//! The entire Task system is heavily founded on Qt. All Tasks have a parent,
-//! except for the root Task, and are considered QObjects. By using Qt's RTTI
+//! The entire Task system is heavily founded on TQt. All Tasks have a tqparent,
+//! except for the root Task, and are considered TQObjects. By using TQt's RTTI
//! facilities (TQObject::sender(), TQObject::isA(), etc), you can use a
//! "fire and forget" approach with Tasks.
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
index 9e2fc061..2d13db79 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/xmpp_tasks.cpp
@@ -35,9 +35,9 @@ using namespace XMPP;
static TQString lineEncode(TQString str)
{
- str.replace(TQRegExp("\\\\"), "\\\\"); // backslash to double-backslash
- str.replace(TQRegExp("\\|"), "\\p"); // pipe to \p
- str.replace(TQRegExp("\n"), "\\n"); // newline to \n
+ str.tqreplace(TQRegExp("\\\\"), "\\\\"); // backslash to double-backslash
+ str.tqreplace(TQRegExp("\\|"), "\\p"); // pipe to \p
+ str.tqreplace(TQRegExp("\n"), "\\n"); // newline to \n
return str;
}
@@ -103,8 +103,8 @@ public:
int type;
};
-JT_Register::JT_Register(Task *parent)
-:Task(parent)
+JT_Register::JT_Register(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
d->type = -1;
@@ -246,8 +246,8 @@ public:
JT_Register *jt_reg;
};
-JT_UnRegister::JT_UnRegister(Task *parent)
-: Task(parent)
+JT_UnRegister::JT_UnRegister(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
d->jt_reg = 0;
@@ -306,8 +306,8 @@ public:
TQValueList<TQDomElement> itemList;
};
-JT_Roster::JT_Roster(Task *parent)
-:Task(parent)
+JT_Roster::JT_Roster(Task *tqparent)
+:Task(tqparent)
{
type = -1;
d = new Private;
@@ -448,8 +448,8 @@ bool JT_Roster::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_PushRoster
//----------------------------------------------------------------------------
-JT_PushRoster::JT_PushRoster(Task *parent)
-:Task(parent)
+JT_PushRoster::JT_PushRoster(Task *tqparent)
+:Task(tqparent)
{
}
@@ -475,8 +475,8 @@ bool JT_PushRoster::take(const TQDomElement &e)
//----------------------------------------------------------------------------
// JT_Presence
//----------------------------------------------------------------------------
-JT_Presence::JT_Presence(Task *parent)
-:Task(parent)
+JT_Presence::JT_Presence(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -485,7 +485,7 @@ JT_Presence::~JT_Presence()
{
}
-void JT_Presence::pres(const Status &s)
+void JT_Presence::pres(const tqStatus &s)
{
type = 0;
@@ -504,7 +504,7 @@ void JT_Presence::pres(const Status &s)
if(!s.status().isEmpty())
tag.appendChild(textTag(doc(), "status", s.status()));
- tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+ tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
if(!s.keyID().isEmpty()) {
TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -529,7 +529,7 @@ void JT_Presence::pres(const Status &s)
}
}
-void JT_Presence::pres(const Jid &to, const Status &s)
+void JT_Presence::pres(const Jid &to, const tqStatus &s)
{
pres(s);
tag.setAttribute("to", to.full());
@@ -554,8 +554,8 @@ void JT_Presence::onGo()
//----------------------------------------------------------------------------
// JT_PushPresence
//----------------------------------------------------------------------------
-JT_PushPresence::JT_PushPresence(Task *parent)
-:Task(parent)
+JT_PushPresence::JT_PushPresence(Task *tqparent)
+:Task(tqparent)
{
}
@@ -569,7 +569,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
return false;
Jid j(e.attribute("from"));
- Status p;
+ tqStatus p;
if(e.hasAttribute("type")) {
TQString type = e.attribute("type");
@@ -593,7 +593,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
tag = findSubTag(e, "status", &found);
if(found)
- p.setStatus(tagContent(tag));
+ p.settqStatus(tagContent(tag));
tag = findSubTag(e, "show", &found);
if(found)
p.setShow(tagContent(tag));
@@ -653,10 +653,10 @@ bool JT_PushPresence::take(const TQDomElement &e)
//----------------------------------------------------------------------------
static TQDomElement oldStyleNS(const TQDomElement &e)
{
- // find closest parent with a namespace
- TQDomNode par = e.parentNode();
+ // find closest tqparent with a namespace
+ TQDomNode par = e.tqparentNode();
while(!par.isNull() && par.namespaceURI().isNull())
- par = par.parentNode();
+ par = par.tqparentNode();
bool noShowNS = false;
if(!par.isNull() && par.namespaceURI() == e.namespaceURI())
noShowNS = true;
@@ -676,7 +676,7 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
if(!noShowNS)
i.setAttribute("xmlns", e.namespaceURI());
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -688,8 +688,8 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
return i;
}
-JT_Message::JT_Message(Task *parent, const Message &msg)
-:Task(parent)
+JT_Message::JT_Message(Task *tqparent, const Message &msg)
+:Task(tqparent)
{
m = msg;
m.setId(id());
@@ -724,7 +724,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
// find closest xmlns
TQDomNode n = e;
while(!n.isNull() && !n.toElement().hasAttribute("xmlns"))
- n = n.parentNode();
+ n = n.tqparentNode();
TQString ns;
if(n.isNull() || !n.toElement().hasAttribute("xmlns"))
ns = "jabber:client";
@@ -742,7 +742,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
i.setAttributeNodeNS(al.item(x).cloneNode().toAttr());
}
- // copy children
+ // copy tqchildren
TQDomNodeList nl = e.childNodes();
for(x = 0; x < nl.count(); ++x) {
TQDomNode n = nl.item(x);
@@ -756,8 +756,8 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
return i;
}
-JT_PushMessage::JT_PushMessage(Task *parent)
-:Task(parent)
+JT_PushMessage::JT_PushMessage(Task *tqparent)
+:Task(tqparent)
{
}
@@ -799,8 +799,8 @@ public:
TQString message;
};
-JT_GetLastActivity::JT_GetLastActivity(Task *parent)
-:Task(parent)
+JT_GetLastActivity::JT_GetLastActivity(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
}
@@ -858,8 +858,8 @@ bool JT_GetLastActivity::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_GetServices
//----------------------------------------------------------------------------
-JT_GetServices::JT_GetServices(Task *parent)
-:Task(parent)
+JT_GetServices::JT_GetServices(Task *tqparent)
+:Task(tqparent)
{
}
@@ -955,8 +955,8 @@ public:
VCard vcard;
};
-JT_VCard::JT_VCard(Task *parent)
-:Task(parent)
+JT_VCard::JT_VCard(Task *tqparent)
+:Task(tqparent)
{
type = -1;
d = new Private;
@@ -1055,8 +1055,8 @@ public:
TQValueList<SearchResult> resultList;
};
-JT_Search::JT_Search(Task *parent)
-:Task(parent)
+JT_Search::JT_Search(Task *tqparent)
+:Task(tqparent)
{
d = new Private;
type = -1;
@@ -1187,8 +1187,8 @@ bool JT_Search::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_ClientVersion
//----------------------------------------------------------------------------
-JT_ClientVersion::JT_ClientVersion(Task *parent)
-:Task(parent)
+JT_ClientVersion::JT_ClientVersion(Task *tqparent)
+:Task(tqparent)
{
}
@@ -1258,8 +1258,8 @@ const TQString & JT_ClientVersion::os() const
//----------------------------------------------------------------------------
// JT_ClientTime
//----------------------------------------------------------------------------
-/*JT_ClientTime::JT_ClientTime(Task *parent, const Jid &_j)
-:Task(parent)
+/*JT_ClientTime::JT_ClientTime(Task *tqparent, const Jid &_j)
+:Task(tqparent)
{
j = _j;
iq = createIQ("get", j.full(), id());
@@ -1307,8 +1307,8 @@ bool JT_ClientTime::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_ServInfo
//----------------------------------------------------------------------------
-JT_ServInfo::JT_ServInfo(Task *parent)
-:Task(parent)
+JT_ServInfo::JT_ServInfo(Task *tqparent)
+:Task(tqparent)
{
}
@@ -1338,12 +1338,12 @@ bool JT_ServInfo::take(const TQDomElement &e)
// TQDomElement query = doc()->createElement("query");
// query.setAttribute("xmlns", "jabber:iq:time");
// iq.appendChild(query);
- // TQDateTime local = TQDateTime::currentDateTime();
+ // TQDateTime local = TQDateTime::tqcurrentDateTime();
// TQDateTime utc = local.addSecs(-getTZOffset() * 3600);
// TQString str = getTZString();
// query.appendChild(textTag("utc", TS2stamp(utc)));
// query.appendChild(textTag("tz", str));
- // query.appendChild(textTag("display", TQString("%1 %2").arg(local.toString()).arg(str)));
+ // query.appendChild(textTag("display", TQString("%1 %2").tqarg(local.toString()).tqarg(str)));
// send(iq);
// return TRUE;
//}
@@ -1417,7 +1417,7 @@ bool JT_ServInfo::take(const TQDomElement &e)
}
else if (node.startsWith(client()->capsNode() + "#")) {
TQString ext = node.right(node.length()-client()->capsNode().length()-1);
- if (client()->extensions().contains(ext)) {
+ if (client()->extensions().tqcontains(ext)) {
const TQStringList& l = client()->extension(ext).list();
for ( TQStringList::ConstIterator it = l.begin(); it != l.end(); ++it ) {
feature = doc()->createElement("feature");
@@ -1444,8 +1444,8 @@ bool JT_ServInfo::take(const TQDomElement &e)
//----------------------------------------------------------------------------
// JT_Gateway
//----------------------------------------------------------------------------
-JT_Gateway::JT_Gateway(Task *parent)
-:Task(parent)
+JT_Gateway::JT_Gateway(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -1539,8 +1539,8 @@ public:
AgentItem root;
};
-JT_Browse::JT_Browse (Task *parent)
-:Task (parent)
+JT_Browse::JT_Browse (Task *tqparent)
+:Task (tqparent)
{
d = new Private;
}
@@ -1664,8 +1664,8 @@ public:
DiscoList items;
};
-JT_DiscoItems::JT_DiscoItems(Task *parent)
-: Task(parent)
+JT_DiscoItems::JT_DiscoItems(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1753,8 +1753,8 @@ public:
DiscoItem item;
};
-JT_DiscoInfo::JT_DiscoInfo(Task *parent)
-: Task(parent)
+JT_DiscoInfo::JT_DiscoInfo(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1895,8 +1895,8 @@ public:
DiscoList list;
};
-JT_DiscoPublish::JT_DiscoPublish(Task *parent)
-: Task(parent)
+JT_DiscoPublish::JT_DiscoPublish(Task *tqparent)
+: Task(tqparent)
{
d = new Private;
}
@@ -1959,8 +1959,8 @@ bool JT_DiscoPublish::take(const TQDomElement &x)
//----------------------------------------------------------------------------
// JT_MucPresence
//----------------------------------------------------------------------------
-JT_MucPresence::JT_MucPresence(Task *parent)
-:Task(parent)
+JT_MucPresence::JT_MucPresence(Task *tqparent)
+:Task(tqparent)
{
type = -1;
}
@@ -1969,7 +1969,7 @@ JT_MucPresence::~JT_MucPresence()
{
}
-void JT_MucPresence::pres(const Status &s)
+void JT_MucPresence::pres(const tqStatus &s)
{
type = 0;
@@ -1988,7 +1988,7 @@ void JT_MucPresence::pres(const Status &s)
if(!s.status().isEmpty())
tag.appendChild(textTag(doc(), "status", s.status()));
- tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+ tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
if(!s.keyID().isEmpty()) {
TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -2013,7 +2013,7 @@ void JT_MucPresence::pres(const Status &s)
}
}
-void JT_MucPresence::pres(const Jid &to, const Status &s, const TQString &password)
+void JT_MucPresence::pres(const Jid &to, const tqStatus &s, const TQString &password)
{
pres(s);
tag.setAttribute("to", to.full());
@@ -2043,8 +2043,8 @@ class JT_PrivateStorage::Private
int type;
};
-JT_PrivateStorage::JT_PrivateStorage(Task *parent)
- :Task(parent)
+JT_PrivateStorage::JT_PrivateStorage(Task *tqparent)
+ :Task(tqparent)
{
d = new Private;
}